@@ -23,6 +23,7 @@ echo "Checking for SliTaz cmdline options..."
 # This option is not handled by a loop and case like others and has no
 # effect on an installed system.
 if ! grep -q "100[0-9]:100" /etc/passwd; then
+
 	if fgrep -q "user=" /proc/cmdline; then
 		USER=$(cat /proc/cmdline | sed 's/.*user=\([^ ]*\).*/\1/')
 		# Avoid usage of an existing system user or root.
@@ -32,19 +33,21 @@ if ! grep -q "100[0-9]:100" /etc/passwd; then
 	else
 		USER=tux
 	fi
+	
+	# Make sure we have users applications.conf
+	if [ ! -f "/etc/skel/.config/slitaz/applications.conf" ]; then
+		mkdir -p /etc/skel/.config/slitaz
+		cp /etc/slitaz/applications.conf /etc/skel/.config/slitaz
+	fi
+	
 	echo -n "Configuring user and group: $USER..."
 	adduser -D -s /bin/sh -g "SliTaz User" -G users -h /home/$USER $USER
 	passwd -d $USER >/dev/null
 	status
-	# Audio and cdrom group.
-	addgroup $USER audio
-	addgroup $USER cdrom
-	addgroup $USER video
-	addgroup $USER tty
-	# Slim default user.
+	
+	# Slim default user
 	if [ -f /etc/slim.conf ]; then
-		sed -i s/"default_user .*"/"default_user        $USER"/\
-			/etc/slim.conf
+		sed -i s/"default_user .*"/"default_user    $USER"/ /etc/slim.conf
 	fi
 fi
 
@@ -93,7 +96,7 @@ do
 				[ -d /home/$USER ] && mv /home/$USER /tmp/$USER-files
 				mount /dev/$DEVID /home &&
 				case "$(/sbin/blkid | grep /dev/$DEVID:)" in
-				*\"ntfs\"*|*\"vfat\"*) mount.posixovl -F /home ;;
+				*\"ntfs\"*|*\"vfat\"*) mount.posixovl -F /home -- -oallow_other -odefault_permissions -osuid ;;
 				esac
 				mount /home -o remount,uid=1000,gid=100 2>/dev/null
 				# Check if swap file must be generated in /home: swap=size (Mb).
@@ -180,8 +183,3 @@ do
 			continue ;;
 	esac
 done
-
-# If no default WM fallback to Openbox (we never know).
-if [ ! -f /etc/X11/wm.default ]; then
-	echo "openbox" > /etc/X11/wm.default
-fi
